@@ -422,12 +422,22 @@ let lookup_immediate key dict =
   | Dictionary d | Stream {contents = (Dictionary d, _)} -> lookup_string_compare key d
   | _ -> None
 
+let lookup_direct_or_array pdf name obj =
+  match explode name with
+  | '/'::'['::num ->
+      let digits, _ = cleavewhile isdigit num in
+        begin match obj with
+        | Array a -> Some (direct pdf (List.nth a (int_of_string (implode digits))))
+        | _ -> None
+        end
+  | _ -> lookup_direct pdf name obj
+
 (* Follow a nested chain of dictionary entries. *)
 let rec lookup_chain pdf obj = function
   | [] -> Some obj
-  | [n] -> lookup_direct pdf n obj
+  | [n] -> lookup_direct_or_array pdf n obj
   | n::ns ->
-      match lookup_direct pdf n obj with
+      match lookup_direct_or_array pdf n obj with
       | Some obj' -> lookup_chain pdf obj' ns
       | None -> None
 
@@ -451,30 +461,62 @@ let addobj_given_num doc (num, obj) =
     pdfobjmap_add num (ref (Parsed obj), 0) doc.objects.pdfobjects
 
 (* Follow a chain from the root, finding a dictionary entry to replace (or add).
-   Keep the same direct / indirect structure as is already present. NB this
-   cannot create a dictionary or tree of dictionaries which are not already
-   there, because the information about direct / indirect is not present. *)
+   Keep the same direct / indirect structure as is already present - any
+   terminal chain of previously-absent dictionaries will be created in direct
+   form. *)
 
 (* Find the final indirect object in the chain, returning its number and the
    remaining (fully-direct) chain *)
 let rec find_final_indirect remaining_chain pdf obj objnum = function
   | [] -> (objnum, rev remaining_chain)
   | k::ks ->
-      match indirect_number pdf k obj with
-      | Some i -> find_final_indirect [] pdf (lookup_obj pdf i) i ks
-      | None ->
-          match lookup_immediate k obj with
-          | Some obj -> find_final_indirect (k::remaining_chain) pdf obj objnum ks
-          | None -> assert false (* chain pre-checked by lookup_chain *)
+      match explode k with
+      | '/'::'['::num ->
+          let digits, _ = cleavewhile isdigit num in
+            begin match obj with
+            | Array a ->
+                begin match List.nth a (int_of_string (implode digits)) with
+                | Indirect i -> find_final_indirect [] pdf (lookup_obj pdf i) i ks
+                | newobj -> find_final_indirect (k::remaining_chain) pdf newobj objnum ks
+                end
+            | _ -> assert false (* chain pre-checked by lookup_chain *)
+            end
+      | _ ->
+         match indirect_number pdf k obj with
+         | Some i -> find_final_indirect [] pdf (lookup_obj pdf i) i ks
+         | None ->
+             match lookup_immediate k obj with
+             | Some obj -> find_final_indirect (k::remaining_chain) pdf obj objnum ks
+             | None -> assert false (* chain pre-checked by lookup_chain *)
 
 (* The object number is now chosen. We follow what remains of the chain and insert
 the new key-value pair. *)
 let rec replace_chain_all_direct finalobj chain (k, v) =
   match finalobj with
-  | Dictionary _ as d | Stream ({contents = (d, _)}) ->
+  | Dictionary dd as d | Stream ({contents = (Dictionary dd as d, _)}) ->
       begin match chain with
       | [] -> add_dict_entry d k v
-      | c::cs -> add_dict_entry d c (replace_chain_all_direct finalobj cs (k, v))
+      | c::cs -> add_dict_entry d c (replace_chain_all_direct (unopt (lookup c dd)) cs (k, v))
+      end
+  | Array a ->
+      begin match chain with
+      | [] ->
+          (* Put the value in the array at the position indictated by the 'key' *)
+          begin match explode k with
+          | '/'::'['::num ->
+              let digits, _ = cleavewhile isdigit num in
+              let n = int_of_string (implode digits) in
+                Array (List.mapi (fun n' e -> if n' = n then v else e) a)
+          | _ -> 
+          raise (PDFError "replace_chain_all_direct: nothing to put in array")
+          end
+      | c::cs ->
+          match explode c with
+          | '/'::'['::num ->
+              let digits, _ = cleavewhile isdigit num in
+              let n = int_of_string (implode digits) in
+                Array (List.mapi (fun n' e -> if n' = n then (replace_chain_all_direct e cs (k, v)) else e) a)
+          | _ -> raise (PDFError "replace_chain_all_direct: bad array chain")
       end
   | _ -> raise (PDFError "replace_chain_all_direct: bad chain")
 
@@ -486,9 +528,10 @@ let replace_chain_exists pdf chain (k, v) =
       | [] -> raise (PDFError "no chain")
       | chain ->
           let finalobjnum, remaining_chain = find_final_indirect [] pdf pdf.trailerdict 0 chain in
-            if finalobjnum = 0 then raise (PDFError "cannot use replace_chain to set trailer dictonary") else
-              let newobj = replace_chain_all_direct (lookup_obj pdf finalobjnum) remaining_chain (k, v) in
-                addobj_given_num pdf (finalobjnum, newobj)
+            let newobj =
+              replace_chain_all_direct (if finalobjnum = 0 then pdf.trailerdict else lookup_obj pdf finalobjnum) remaining_chain (k, v)
+            in
+              if finalobjnum = 0 then pdf.trailerdict <- newobj else addobj_given_num pdf (finalobjnum, newobj)
 
 let replace_chain pdf chain obj =
   let rec find_max_existing to_fake chain =
@@ -512,6 +555,9 @@ let replace_chain pdf chain obj =
         else
           replace_chain_exists pdf chain (key, obj)
 
+(* FIXME When the final item in the chain is indirect, shouldn't it be kept indirect and the object just replaced? *)
+(* FIXME Add remove_chain *)
+
 (* Look up under a key and its alternate. Return the value associated
 with the key that worked, or [None] if neither did. *)
 let lookup_direct_orelse pdf k k' d =
@@ -568,6 +614,11 @@ let objiter f doc =
   in
     pdfobjmap_iter f' doc.objects.pdfobjects
 
+let objselect p doc =
+  let ns = ref [] in
+    objiter (fun n obj -> if p obj then ns =| n) doc;
+    !ns
+
 let objselfmap f doc =
   resolve_all_delayed_object_streams doc;
   let rec f' k v =
