@@ -43,7 +43,7 @@ type subtype =
   | TrapNet
   | Watermark
   | ThreeDee
-  | Unknown
+  | Unknown of string
 
 (* Main type. 'rest' contains the raw annotation dictionary with the exception
 of the entries corresponding to the other items in the record. *)
@@ -69,13 +69,34 @@ let rec read_annotation pdf annot =
             begin match lookup "/Parent" d with
             | Some (Pdf.Indirect i) ->
                 Popup (read_annotation pdf (Pdf.Indirect i))
-            | _ -> Unknown
+            | _ -> Unknown ""
             end
         | _ -> raise (Pdf.PDFError "read_annotation failed")
         end
     | Some (Pdf.Name "/Stamp") -> Stamp
     | Some (Pdf.Name "/Link") -> Link
-    | _ -> Unknown
+    | Some (Pdf.Name "/Line") -> Line
+    | Some (Pdf.Name "/Square") -> Square
+    | Some (Pdf.Name "/Circle") -> Circle
+    | Some (Pdf.Name "/Polygon") -> Polygon
+    | Some (Pdf.Name "/PolyLine") -> PolyLine
+    | Some (Pdf.Name "/Highlight") -> Highlight
+    | Some (Pdf.Name "/Underline") -> Underline
+    | Some (Pdf.Name "/Squiggly") -> Squiggly
+    | Some (Pdf.Name "/StrikeOut") -> StrikeOut
+    | Some (Pdf.Name "/Caret") -> Caret
+    | Some (Pdf.Name "/Ink") -> Ink
+    | Some (Pdf.Name "/FileAttachment") -> FileAttachment
+    | Some (Pdf.Name "/Sound") -> Sound
+    | Some (Pdf.Name "/Movie") -> Movie
+    | Some (Pdf.Name "/Widget") -> Widget
+    | Some (Pdf.Name "/Screen") -> Screen
+    | Some (Pdf.Name "/PrinterMark") -> PrinterMark
+    | Some (Pdf.Name "/TrapNet") -> TrapNet
+    | Some (Pdf.Name "/Watermark") -> Watermark
+    | Some (Pdf.Name "/3D") -> ThreeDee
+    | Some (Pdf.Name n) -> Unknown n
+    | _ -> Unknown ""
   in let contents =
     match Pdf.lookup_direct pdf "/Contents" annot with
     | Some (Pdf.String s) -> Some s
@@ -149,7 +170,7 @@ let rec read_annotation pdf annot =
     | Pdf.Dictionary entries ->
         Pdf.Dictionary
           (lose
-            (fun (k, _) -> mem k ["/Subtype"; "/Contents"; "/Rect"; "/Border"])
+            (fun (k, _) -> mem k ["/Subtype"; "/Contents"; "/Rect"; "/Border"; "/Subj"; "/BS"; "/C"])
             entries)
     | _ -> raise (Pdf.PDFError "Bad annotation dictionary")
   in
@@ -197,7 +218,7 @@ let string_of_subtype = function
   | Caret -> "/Caret" | Ink -> "/Ink" | FileAttachment -> "/FileAttachment" | Sound -> "/Sound"
   | Movie -> "/Movie" | Widget -> "/Widget" | Screen -> "/Screen"
   | PrinterMark -> "/PrinterMark" | TrapNet -> "/TrapNet" | Watermark -> "/Watermark"
-  | Unknown -> "/Unknown" | Popup _ -> "/Popup" | ThreeDee -> "/3D"
+  | Unknown _ -> "/Unknown" | Popup _ -> "/Popup" | ThreeDee -> "/3D"
 
 let obj_of_annot t =
   let d =
