@@ -1071,22 +1071,56 @@ let decode_CCITTFax k eol eba c r eob bone dra input =
             | End_of_file -> bytes_of_write_bitstream output
             | _ -> raise (Failure "Bad CCITT Stream") 
 
+(* CCITT Group 3 encoder *)
+
+(* Data comes in as bytes, with each scanline padded with zeroes. In addition,
+   it is padded to bytes at the end. (Why though? Check for our case.)
+
+Output is suitable for /CCITTFaxDecode /Columns <columns> /K 0 with all other
+dictionary entries as default. i.e: *)
+
+(* Return colour of run, and non-zero length of run (must make progress) *)
+let read_run maxcols i =
+  let nbits = ref 1 in
+  let iswhite = ref (Pdfio.getbit i) in
+  let fin = ref false in
+    while !nbits < maxcols && not !fin do
+      let pos = ref (Pdfio.bitstream_pos i) in
+      let newbit = Pdfio.getbit i in
+      if newbit = !iswhite then nbits += 1 else (Pdfio.bitstream_seek i !pos; set fin)
+    done;
+    (!iswhite, !nbits)
+
+let encode_ccitt columns stream =
+  let i = Pdfio.bitbytes_of_input (Pdfio.input_of_bytes stream) in
+  let o = Pdfio.make_write_bitstream () in
+    try
+      let cols_left = ref columns in
+        while true do
+          let iswhite, length = read_run !cols_left i in
+            let bits = (if iswhite then write_white_code else write_black_code) length in
+              iter (Pdfio.putbit o) bits;
+              if not iswhite && !cols_left = columns then iter (Pdfio.putbit o) (write_black_code 0);
+              cols_left -= length;
+              if !cols_left = 0 then cols_left := columns;
+        done;
+        mkbytes 0
+    with
+      End_of_file ->
+        iter (Pdfio.putbit o) (write_white_code ~-1);
+        iter (Pdfio.putbit o) (write_white_code ~-1);
+        Pdfio.align_write o;
+        bytes_of_write_bitstream o
+
 (* CCITT Group 4 encoder *)
 
 (* Data comes in as bytes, with each scanline padded with zeroes. In addition,
    it is padded to bytes at the end. (Why though? Check for our case.)
 
 Output is suitable for /CCITTFaxDecode /Columns <columns> /K -1 with all other
-dictionary entries as default. i.e:
+dictionary entries as default. *)
 
-/EndOfLine false
-/EncodedByteAlign false
-/Rows 0
-/EndOfBlock true
-/BlackIs1 false
-/DamagedRowsBeforeError 0 *)
-
-let encode_ccitt columns stream = stream
+let encode_ccittg4 columns stream = stream
 
 (* Tester. *)
 (*let _ =
