@@ -10,7 +10,8 @@ type targetpage =
 type t =
   | Action of Pdf.pdfobject
   | NullDestination
-  | NamedDestinationElsewhere of string
+  | NamedDestination of string
+  | StringDestination of string
   | XYZ of targetpage * float option * float option * float option
   | Fit of targetpage
   | FitH of targetpage * float option
@@ -20,11 +21,13 @@ type t =
   | FitBH of targetpage * float option
   | FitBV of targetpage * float option
 
-(** Read a destination given a PDF and destionation object. *)
-val read_destination : Pdf.t -> Pdf.pdfobject -> t
+(** Read a destination given a PDF and destination object. If [shallow] is
+    true, actions will be kept in PDF form, rather than followed to their
+    destinations.  *)
+val read_destination : ?shallow:bool -> Pdf.t -> Pdf.pdfobject -> t
 
 (** Write a destination to a [Pdf.pdfobject]. *)
 val pdfobject_of_destination : t -> Pdf.pdfobject
 
 (** Transform a destination by a matrix *)
-val transform_destination : Pdftransform.transform_matrix -> t -> t
+val transform_destination : Pdf.t -> Pdftransform.transform_matrix -> t -> t
