@@ -11,31 +11,9 @@ type pixel_layout =
 type t =
   | JPEG of bytes * float list option
   | JPEG2000 of bytes * float list option
-  | JBIG2 of bytes * float list option
+  | JBIG2 of bytes * float list option * int option
   | Raw of int * int * pixel_layout * bytes
 
-let string_of_layout = function
-  | BPP1 -> "BPP1"
-  | BPP8 -> "BPP8"
-  | BPP24 -> "BPP24"
-  | BPP48 -> "BPP48"
-
-let string_of_image = function
-  | JPEG _ -> "JPEG"
-  | JPEG2000 _ -> "JPEG2000"
-  | JBIG2 _ -> "JBIG2"
-  | Raw (w, h, layout, data) ->
-      "RAW: " ^ string_of_int w ^ " " ^ string_of_int h
-      ^ " " ^ string_of_layout layout ^ " bytes of data = "
-      ^ string_of_int (bytes_size data)
-
-let print_floats fs =
-  for x = 1 to Array.length fs do
-    print_float fs.(x - 1);
-    print_string " "
-  done;
-  print_string "\n"
-
 (* Decodes an image in-place, given an array of floats. Assumes that output of Decode fits into same number of bits as input of Decode. FIXME: When might this not be true? *)
 
 (* Invert the bits in a bytes *)
@@ -472,26 +450,6 @@ let get_raw_image pdf resources width height dict data =
       (*i Pdf.log (Printf.sprintf ((Pdfwrite.string_of_pdf (Pdf.direct pdf dict)))); i*)
       raise e 
 
-(* Print some debug information about an image. *)
-let print_image pdf resources img =
-  (*i Printf.printf "-----------------------------------------------------\n";
-  Printf.printf "Image Dictionary:\n%s\n" (Pdfwrite.string_of_pdf img); i*)
-  let w = match Pdf.lookup_direct pdf "/Width" img with Some (Pdf.Integer n) -> n | _ ->  0
-  in let h = match Pdf.lookup_direct pdf "/Height" img with Some (Pdf.Integer n)-> n | _ -> 0 in
-    Printf.printf "Width is %i, height %i\n" w h;
-  begin match Pdf.lookup_direct pdf "/ColorSpace" img with
-  | Some cs -> Printf.printf "Colourspace is...%s\n" (Pdfspace.string_of_colourspace (Pdfspace.read_colourspace pdf resources cs))
-  | None -> Printf.printf "No Colourspace\n"
-  end;
-  begin match Pdf.lookup_direct pdf "/BitsPerComponent" img with
-  | Some (Pdf.Integer n) -> Printf.printf "%i Bits Per Component\n" n
-  | _ -> Printf.printf "No /BitsPerComponent\n"
-  end;
-  begin match Pdf.lookup_direct pdf "/Decode" img with
-  | Some decode -> Printf.printf "Decode Array: %s\n" (Pdfwrite.string_of_pdf decode)
-  | None -> Printf.printf "No /Decode Array\n"
-  end
-
 let get_image_24bpp pdf resources stream =
   (*i flprint "\n";
   print_image pdf resources (Pdf.direct pdf stream);
@@ -553,161 +511,19 @@ let get_image_24bpp pdf resources stream =
             | Some (Pdf.Name ("/DCTDecode" | "/DCT"))
             | Some (Pdf.Array [Pdf.Name ("/DCTDecode" | "/DCT")]) -> JPEG (s, get_decode ())
             | Some (Pdf.Name "/JBIG2Decode")
-            | Some (Pdf.Array [Pdf.Name "/JBIG2Decode"]) -> JBIG2 (s, get_decode ())
+            | Some (Pdf.Array [Pdf.Name "/JBIG2Decode"]) ->
+                let globals =
+                  match lookup "/DecodeParms" d with
+                  | Some (Pdf.Dictionary d) ->
+                      begin match lookup "/JBIG2Globals" d with
+                      | Some (Pdf.Indirect i) -> Some i
+                      | _ -> None
+                      end
+                  | _ -> None
+                in
+                  JBIG2 (s, get_decode (), globals)
             | Some (Pdf.Name "/JPXDecode")
             | Some (Pdf.Array [Pdf.Name "/JPXDecode"]) -> JPEG2000 (s, get_decode ())
             | _ -> raise (Pdf.PDFError "decode_to_image")
             end
       | _ -> assert false
-
-(* For now, this just knows how to do 1bpp specially, since this causes enormous
-memory headaches in pdf2xar *)
-let get_image pdf resources stream =
-  let stream = Pdf.direct pdf stream in
-    let streamdict, data =
-      Pdf.getstream stream;
-      match stream with
-      | Pdf.Stream {contents = (s, Pdf.Got d)} -> s, d
-      | _ -> assert false (*r [Pdf.getstream] would have failed *)
-    in
-    let components =
-      let colourspace =
-        match Pdf.lookup_direct_orelse pdf "/ColorSpace" "/CS" stream with
-        | None -> Pdf.Name "/DeviceGray" (* This is for image masks, in which the colourspace is implicitly 1 bpp *)
-        | Some x -> x
-        in
-          Pdfops.components pdf resources colourspace 
-  and bpc =
-      match Pdf.lookup_direct_orelse pdf "/BitsPerComponent" "/BPC" streamdict
-      with
-      | Some (Pdf.Integer i) -> i
-      | _ -> raise (Pdf.PDFError "bad /BitsPerComponent")
-  and colorspace =
-    (* If an image mask, it's /DeviceGray, effectively *)
-    match Pdf.lookup_direct_orelse pdf "/ImageMask" "/IM" stream with
-    | Some (Pdf.Boolean true) -> Pdfspace.DeviceGray
-    | _ ->
-      let colspace =
-        Pdf.lookup_direct_orelse pdf "/ColorSpace" "/CS" stream
-      in
-        let space =
-          match Pdf.lookup_direct pdf "/ColorSpace" resources, colspace with
-          | Some (Pdf.Dictionary _ as d), Some (Pdf.Name c) ->
-              begin match Pdf.lookup_direct pdf c d with
-              | Some colspace -> colspace
-              | _ -> (Pdf.Name c)
-              end
-          | _ ->
-              match colspace with
-              | Some c -> c
-              | _ -> raise (Pdf.PDFError "PDf image: no colourspace")
-        in
-          Pdfspace.read_colourspace pdf resources space
-  in
-      (*i Printf.printf "get_image: %i components, %i bits per component\n" components bpc;
-      Printf.printf "colorspace is %s\n" (Pdfspace.string_of_colourspace
-      colorspace); i*)
-      match bpc, components, colorspace with
-      | (8 | 1), 1, (Pdfspace.DeviceGray | Pdfspace.DeviceRGB | Pdfspace.CalGray _ | Pdfspace.CalRGB _) ->
-        (* 1bpp black and white and 8bpp greyscale special case *)
-        begin
-          let width = 
-            match (Pdf.lookup_direct_orelse pdf "/Width" "/W" streamdict) with
-            | Some (Pdf.Integer x) -> x
-            | _ -> raise (Pdf.PDFError "Malformed /Image width")
-          and height =
-            match (Pdf.lookup_direct_orelse pdf "/Height" "/H" streamdict) with
-            | Some (Pdf.Integer x) -> x
-            | _ -> raise (Pdf.PDFError "Malformed /Image height")
-          in
-            decode_to_image pdf stream;
-            begin match stream with
-            | Pdf.Stream {contents = (Pdf.Dictionary d) as dict, Pdf.Got s} ->
-          let get_decode () =
-            let decode_entry = Pdf.lookup_direct_orelse pdf "/Decode" "/D" dict in
-              let decode_entry = decode_defaults pdf resources decode_entry dict in
-                match decode_entry with
-                | Some (Pdf.Array nums) ->
-                    Some (map (function Pdf.Real n -> n | Pdf.Integer i -> float i | _ -> 0.) nums)
-                | _ -> None
-          in
-            begin match Pdf.lookup_direct_orelse pdf "/Filter" "/F" dict with
-            | None | Some (Pdf.Array []) ->
-                (* Now, fetch the raw data from the stream and, if necessary.
-                apply the decode... *)
-                let s =
-                  if get_decode () = Some [1.; 0.] then
-                    let s = copybytes s in
-                      bytes_selfmap (if bpc = 1 then lnot else (function x -> 255 - x)) s;
-                      s
-                  else
-                    s
-                in       
-                  Raw (width, height, (if bpc = 1 then BPP1 else BPP8), s)
-            | Some (Pdf.Name ("/DCTDecode" | "/DCT"))
-            | Some (Pdf.Array [Pdf.Name ("/DCTDecode" | "/DCT")]) -> JPEG (s, get_decode ())
-            | Some (Pdf.Name "/JBIG2Decode")
-            | Some (Pdf.Array [Pdf.Name "/JBIG2Decode"]) -> JBIG2 (s, get_decode ())
-            | Some (Pdf.Name "/JPXDecode")
-            | Some (Pdf.Array [Pdf.Name "/JPXDecode"]) -> JPEG2000 (s, get_decode ())
-            | _ -> raise (Pdf.PDFError "decode_to_image")
-            end
-            | _ -> raise (Pdf.PDFError "get_image")
-            end
-     end
-  | _ -> get_image_24bpp pdf resources stream
-
-let get_image_raw_24bpp (pdf : Pdf.t) (resources : Pdf.pdfobject) (stream : Pdf.pdfobject) =
-  (raise (Pdf.PDFError "get_image not implemented") : t)
-
-let get_image_raw (pdf : Pdf.t) (resources : Pdf.pdfobject) (stream : Pdf.pdfobject) =
-  (raise (Pdf.PDFError "get_image not implemented") : t)
-
-(** Return a function which, when given an x and y coordinate, returns the pixel
-byte values prior to any decoding, i.e in the raw input image data before /Decode,
-/Index lookups and so on. Returns array of components as bytes.
-This function is needed because color key masking is defined in terms of the
-pixel values of undecoded images. *)
-let get_image_unprocessed_pixel pdf resources stream =
-  (* 1. Need to getstream / uncompress the image as normal (including any
-  predictor), if not already done. *)
-  Pdf.getstream stream;
-  decode_to_image pdf stream;
-  (* 1A. If it's JPEG, we can't oblige - Need a JPEG decoder to fix this... *)
-  match stream with
-  | Pdf.Stream {contents = d, Pdf.Got data} ->
-      begin match Pdf.lookup_direct pdf "/Filter" d with
-      | Some (Pdf.Name ("/DCTDecode" | "/DCT" | "/JBIG2Decode" | "/JPXDecode"))
-      | Some (Pdf.Array [Pdf.Name ("/DCTDecode" | "/DCT" | "/JBIG2Decode" | "/JPXDecode")]) -> None
-      | _ ->
-        (* 2. Now, work out how many bytes per pixel - check this *)
-        let bpc =
-          match Pdf.lookup_direct_orelse pdf "/BitsPerComponent" "/BPC" stream with
-          | Some (Pdf.Integer n) -> n
-          | _ -> 0
-        in let nocomponents =
-          let colourspace =
-            match Pdf.lookup_direct pdf "/ColorSpace" stream with
-            | None -> Pdf.Dictionary []
-            | Some x -> x
-          in
-            Pdfops.components pdf resources colourspace 
-        in
-          if bpc <> 8 then None else (* FIXME: Things other than bytes *)
-          (* 3. Return the function, and making sure enough data / error handling done properly. *)
-          Some
-            (fun s ->
-               try
-                 (* Get nocomponents from correct position in data and put in an array... *)
-                 let pos =
-                   s * nocomponents
-                 in
-                   let a = Array.make nocomponents 0 in
-                     for x = 0 to nocomponents - 1 do
-                       a.(x) <- bget data (pos + x)
-                     done;
-                     a 
-               with
-                 _ -> raise (Pdf.PDFError "bad serial in get_image_unprocessed_pixel"))
-      end 
-  | _ -> None 
