@@ -233,9 +233,9 @@ and do_until_no_next_lb ~preserve_actions indent_lb pdf outline output =
     begin let page =
       match Pdf.lookup_direct pdf "/Dest" outline with
       | Some (Pdf.String stringdest) when preserve_actions ->
-          Pdfdest.NamedDestinationElsewhere stringdest
+          Pdfdest.NamedDestination stringdest
       | Some dest ->
-          Pdfdest.read_destination pdf dest
+          Pdfdest.read_destination ~shallow:preserve_actions pdf dest
       | None ->
           match Pdf.lookup_direct pdf "/A" outline with
           | None -> Pdfdest.NullDestination
@@ -243,12 +243,12 @@ and do_until_no_next_lb ~preserve_actions indent_lb pdf outline output =
               if preserve_actions then
                 (* 05/03/2024: Only preserve if there is a name or byte string. If it's a direct destination, don't preserve. *)
                 match Pdf.lookup_direct pdf "/D" action with
-                | Some ((Pdf.Array _) as dest) -> Pdfdest.read_destination pdf dest
+                | Some ((Pdf.Array _) as dest) -> Pdfdest.read_destination ~shallow:preserve_actions pdf dest
                 | _ -> Pdfdest.Action (Pdf.direct pdf action)
               else
                 match Pdf.lookup_direct pdf "/D" action with
                 | None -> Pdfdest.Action (Pdf.direct pdf action)
-                | Some dest -> Pdfdest.read_destination pdf dest
+                | Some dest -> Pdfdest.read_destination ~shallow:preserve_actions pdf dest
     in let opn =
       match Pdf.lookup_direct pdf "/Count" outline with
       | Some (Pdf.Integer i) when i > 0 -> true
@@ -278,7 +278,7 @@ and do_until_no_next_lb ~preserve_actions indent_lb pdf outline output =
     | Some outline -> do_until_no_next_lb ~preserve_actions indent_lb pdf outline output
     end
 
-let read_bookmarks ?(preserve_actions=false) pdf =
+let read_bookmarks ~preserve_actions pdf =
   match Pdf.lookup_direct pdf "/Root" pdf.Pdf.trailerdict with
   | None -> raise (Pdf.PDFError "read_bookmarks - Bad PDF: no root")
   | Some catalog ->
@@ -290,5 +290,5 @@ let read_bookmarks ?(preserve_actions=false) pdf =
               traverse_outlines_lb ~preserve_actions (ref 0) pdf outlines output;
               rev !out
 
-let transform_bookmark tr m =
-  {m with target = Pdfdest.transform_destination tr m.target}
+let transform_bookmark pdf tr m =
+  {m with target = Pdfdest.transform_destination pdf tr m.target}
