@@ -12,8 +12,10 @@ type t =
 (** Debug string from a bookmark. *)
 val string_of_bookmark : t -> string
 
-(** Read the bookmarks from a document. *)
-val read_bookmarks : ?preserve_actions:bool -> Pdf.t -> t list
+(** Read the bookmarks from a document. If [preserve_actions] is set, the
+    [target] preserves actions rather than extracting the resultant rectangle.
+    See discussion of [shallow] in [Pdfdest]. *)
+val read_bookmarks : preserve_actions:bool -> Pdf.t -> t list
 
 (** Remove the bookmarks from a document. *)
 val remove_bookmarks : Pdf.t -> Pdf.t
@@ -22,4 +24,4 @@ val remove_bookmarks : Pdf.t -> Pdf.t
 val add_bookmarks : t list -> Pdf.t -> Pdf.t
 
 (** Transform a bookmark's destination *)
-val transform_bookmark : Pdftransform.transform_matrix -> t -> t
+val transform_bookmark : Pdf.t -> Pdftransform.transform_matrix -> t -> t
