@@ -596,10 +596,16 @@ let add_root pageroot extras pdf =
 
 (* Make sure to supply refnums to speed it up, if you already have them from a
  * previous call to Pdf.page_reference_numbers *)
-let pagenumber_of_target ?fastrefnums pdf = function
+let rec pagenumber_of_target ?fastrefnums pdf = function
  | Pdfdest.NullDestination -> 0
- | Pdfdest.NamedDestinationElsewhere _ -> 0
- | Pdfdest.Action _ -> 0
+ | Pdfdest.NamedDestination _ -> 0
+ | Pdfdest.StringDestination _ -> 0
+ | Pdfdest.Action a ->
+     begin match Pdf.lookup_direct pdf "/S" a, Pdf.lookup_direct pdf "/D" a with
+     | Some (Pdf.Name "/GoTo"), Some dest ->
+         pagenumber_of_target ?fastrefnums pdf (Pdfdest.read_destination pdf dest)
+     | _ -> 0
+     end
  | Pdfdest.XYZ (t, _, _, _) | Pdfdest.Fit t | Pdfdest.FitH (t, _) | Pdfdest.FitV (t, _)
  | Pdfdest.FitR (t, _, _, _, _) | Pdfdest.FitB t | Pdfdest.FitBH (t, _) | Pdfdest.FitBV (t, _) ->
      match t with
@@ -654,8 +660,8 @@ let change_pages_process_bookmarks mattable refnumstable pdf =
     map
       (fun m ->
          let tr = change_pages_find_matrix m.Pdfmarks.target mattable refnumstable in
-           if tr <> Pdftransform.i_matrix then Pdfmarks.transform_bookmark tr m else m)
-      (Pdfmarks.read_bookmarks pdf)
+           if tr <> Pdftransform.i_matrix then Pdfmarks.transform_bookmark pdf tr m else m)
+      (Pdfmarks.read_bookmarks ~preserve_actions:true pdf)
   in
     Pdfmarks.add_bookmarks bookmarks pdf 
 
@@ -664,7 +670,7 @@ let rewrite_dest pdf mattable refnumstable dest =
   let tr = change_pages_find_matrix parsed_dest mattable refnumstable in
     (*Printf.printf "tr is %s\n" (Pdftransform.string_of_matrix tr);*)
     if tr <> Pdftransform.i_matrix then
-      let transformed = Pdfdest.transform_destination tr parsed_dest in
+      let transformed = Pdfdest.transform_destination pdf tr parsed_dest in
       let new_dest = Pdfdest.pdfobject_of_destination transformed in
         Some (Pdf.addobj pdf new_dest)
     else
@@ -996,6 +1002,42 @@ let fixup_destinations pdf =
   | None ->
       ()
 
+(* For all pages in objnumbers, make sure they have no inherited attribues. *)
+let replace_inherit pdf objnumbers =
+  iter
+    (function objnum ->
+       let replace_inherit objnum entry =
+         let obj = Pdf.lookup_obj pdf objnum in
+           (* Find the first parent entry we can which has the correct attribute. *)
+           let rec find_attribute obj =
+             (* Only replace if not there! *)
+             match Pdf.lookup_direct pdf entry obj with
+             | Some _ -> None
+             | _ ->
+               match Pdf.lookup_direct pdf "/Parent" obj with
+               | Some (Pdf.Dictionary parent) ->
+                   (* Does this one have the attribute? If yes,
+                   return, if no carry on looking... Don't use a
+                   direct lookup, because we want to retain the
+                   indirect reference to resources, for example. *)
+                   begin match lookup entry parent with
+                   | Some pdfobj -> Some pdfobj
+                   | None -> find_attribute (Pdf.Dictionary parent)
+                   end
+               | _ -> None (* Got to top, couldn't find anything *)
+           in
+             match find_attribute obj with
+             | None -> ()
+             | Some replacement_attr ->
+                (* Replace the attribute with replacement_attr, updating the page object in place. *)
+                Pdf.addobj_given_num pdf (objnum, Pdf.add_dict_entry obj entry replacement_attr)
+       in
+         replace_inherit objnum "/MediaBox";
+         replace_inherit objnum "/CropBox";
+         replace_inherit objnum "/Rotate";
+         replace_inherit objnum "/Resources")
+    objnumbers
+
 let pdf_of_pages ?(retain_numbering = false) ?(process_struct_tree = false) basepdf range =
   let page_labels =
     if length (Pdfpagelabels.read basepdf) = 0 then [] else
@@ -1009,7 +1051,7 @@ let pdf_of_pages ?(retain_numbering = false) ?(process_struct_tree = false) base
     let firstindex = ref ~-1 in
     let firstindexlevel = ref ~-1 in
     let index = ref ~-1 in
-    let marks = Pdfmarks.read_bookmarks basepdf in
+    let marks = Pdfmarks.read_bookmarks ~preserve_actions:true basepdf in
     let r =
       option_map
         (function m ->
@@ -1083,39 +1125,7 @@ let pdf_of_pages ?(retain_numbering = false) ?(process_struct_tree = false) base
             may fail to exist, leaving pages without Media boxes or
             resources! Inheritable entries are /MediaBox /CropBox /Rotate
             /Resources *)
-            iter
-              (function objnum ->
-                 let replace_inherit objnum entry =
-                   let obj = Pdf.lookup_obj pdf objnum in
-                     (* Find the first parent entry we can which has the correct attribute. *)
-                     let rec find_attribute obj =
-                       (* Only replace if not there! *)
-                       match Pdf.lookup_direct pdf entry obj with
-                       | Some _ -> None
-                       | _ ->
-                         match Pdf.lookup_direct pdf "/Parent" obj with
-                         | Some (Pdf.Dictionary parent) ->
-                             (* Does this one have the attribute? If yes,
-                             return, if no carry on looking... Don't use a
-                             direct lookup, because we want to retain the
-                             indirect reference to resources, for example. *)
-                             begin match lookup entry parent with
-                             | Some pdfobj -> Some pdfobj
-                             | None -> find_attribute (Pdf.Dictionary parent)
-                             end
-                         | _ -> None (* Got to top, couldn't find anything *)
-                     in
-                       match find_attribute obj with
-                       | None -> ()
-                       | Some replacement_attr ->
-                          (* Replace the attribute with replacement_attr, updating the page object in place. *)
-                          Pdf.addobj_given_num pdf (objnum, Pdf.add_dict_entry obj entry replacement_attr)
-                 in
-                   replace_inherit objnum "/MediaBox";
-                   replace_inherit objnum "/CropBox";
-                   replace_inherit objnum "/Rotate";
-                   replace_inherit objnum "/Resources")
-              objnumbers;
+            replace_inherit pdf objnumbers;
             let thetree = pagetree_with_objnumbers true old_pagetree_root_num (source pdf.Pdf.objects.Pdf.maxobjnum) objnumbers 0 in
             (* 2. Kill the old page tree, excepting pages which will appear in the new
             PDF. It will link, via /Parent entries etc, to the new page tree. To do
