@@ -8,8 +8,10 @@ val trim_structure_tree : Pdf.t -> int list -> unit
 val renumber_parent_trees : Pdf.t list -> unit
 
 (** Merge the structure tree given the part-merged PDF and list of original
-    PDFs. Returns the object number of the new structure tree, if any. *)
-val merge_structure_trees : Pdf.t -> Pdf.t list -> int option
+    PDFs. Returns the object number of the new structure tree, if any. If
+    ?add_toplevel_document is true (default false) a PDF/UA-2-style top-level
+    /Document will be added to the structure tree. *)
+val merge_structure_trees : ?add_toplevel_document:bool -> Pdf.t -> Pdf.t list -> int option
 
 (**/**)
 val endpage : (Pdf.t -> int) ref
