@@ -365,7 +365,7 @@ let i64ofi32 = Int64.of_int32
 
 (* Sign extension for integer of number of bits l. *)
 let sign_extend l n =
-  let shift = Nativeint.size - 1 - l in
+  let shift = (if Nativeint.size = 32 then 33 else Nativeint.size) - 1 - l in (* 33 for js_of_ocaml *)
     (n lsl shift) asr shift
 
 (* Set each element of array [a] to value [v]. *)
@@ -548,8 +548,7 @@ let setify_simple l =
     setify_inner [] l
 
 (* The same, preserving the order of the first occurance of each distinct
-element in the input list. FIXME: This is still n^2, of course. How to improve?
-*)
+element in the input list. *)
 let setify_preserving_order l =
   setify_simple (rev l)
 
@@ -562,6 +561,11 @@ let rec sorted_setify prev = function
 let setify l =
   sorted_setify [] (List.sort compare l)
 
+let setify_large l =
+  let h = Hashtbl.create (length l) in
+    iter (fun k -> Hashtbl.replace h k ()) l;
+    Hashtbl.fold (fun k _ acc -> k::acc) h []
+
 (* Remove all elts of l' from l if l, l' sets. *)
 let setminus l l' =
   let rec setminus_inner r l l' =
