@@ -27,20 +27,18 @@ type encryption =
 
 (** {2 Writing to outputs, channels and files.} *)
 
-(** Write a PDF document to an [Pdfio.output], optionally encrypting and/or
-linearizing. For now, linearization will not preserve object streams. If
+(** Write a PDF document to an [Pdfio.output], optionally encrypting. If
 [?preserve_objstm] is set (default is false), object streams which were in the
 original file will be preserved. If [?create_objstm] is set (default is false),
 additional new object streams will be created. To re-encrypt the file using its
 existing encryption, provide the user or owner password in the [?recrypt]
-argument. The unlabelled boolean argument is true if linearization is required.
-*)
+argument. *)
 val pdf_to_output :
   ?preserve_objstm:bool ->
   ?generate_objstm:bool ->
   ?compress_objstm:bool ->
   ?recrypt:string option ->
-  bool -> encryption option -> bool -> Pdf.t -> Pdfio.output -> unit
+  encryption option -> bool -> Pdf.t -> Pdfio.output -> unit
 
 (** As [pdf_to_output] but to an OCaml channel. If the second boolean is set, build a new
 /ID (don't set this for encrypted documents). *)
@@ -49,7 +47,7 @@ val pdf_to_channel :
   ?generate_objstm:bool ->
   ?compress_objstm:bool ->
   ?recrypt:string option -> 
-  bool -> encryption option -> bool -> Pdf.t -> out_channel -> unit
+  encryption option -> bool -> Pdf.t -> out_channel -> unit
 
 (** As [pdf_to_channel] but to a named file. *)
 val pdf_to_file_options :
@@ -57,17 +55,21 @@ val pdf_to_file_options :
   ?generate_objstm:bool ->
   ?compress_objstm:bool ->
   ?recrypt:string option ->
-  bool -> encryption option -> bool -> Pdf.t -> string -> unit
+  encryption option -> bool -> Pdf.t -> string -> unit
 
 (** Simple write to given file name. Equivalent to [pdf_to_file_options false None true] *)
 val pdf_to_file : Pdf.t -> string -> unit
 
 (** {2 String of a PDF object} *)
 
-(** Calculate a string of a pdf object. Due to OCaml's modest limit
-on string length, this should be used only when the length of the output is
-known to be limited (for example for debug purposes). *)
+(** Calculate a string of a pdf object. *)
 val string_of_pdf : Pdf.pdfobject -> string
 
+(** Calculate a string of a pdf object, but include binary data too. *)
+val string_of_pdf_including_data : Pdf.pdfobject -> string
+
 (** For debug, print out the PDFs objects to standard output. *)
 val debug_whole_pdf : Pdf.t -> unit
+
+(** Convert a PDF string to Hex PDF string representation *)
+val make_hex_pdf_string : string -> string
